/**
 * Configuration file for apeman projects.
 * @see https://github.com/apeman-labo/apeman
 */

'use strict'

module.exports = {
  /**
   * Current working directory path
   */
  get $cwd () {
    return __dirname
  },
  /**
   * Package data
   */
  get $pkg () {
    return require('./package.json')
  },
  /**
   * Prototype projects
   */
  get $proto () {
    return [
      require('apeman-proto-abstract')
    ]
  },
  /**
   * apeman tmpl configurations.
   * @see https://github.com/apeman-cmd-labo/apeman-tmpl
   */
  get $tmpls () {
    const bud = require('apeman-tmpl-bud')

    let $ctx = this.$ctx || {}
    let $vars = this.$vars || {}

    let testDir = $ctx.testDir || $vars.TEST_DEFAULT_DIR

    return {
      [`${testDir}/.test.js.bud`]: bud({
        'type': 'test',
        'runner': 'mocha',
        'src': '../+(lib)/**/*.js'
      })
    }
  },
  /**
   * apeman task configurations.
   * @see https://github.com/apeman-cmd-labo/apeman-task
   */
  get $tasks () {
    const mkdir = require('apeman-task-mkdir')
    const coz = require('apeman-task-coz')

    let $ctx = this.$ctx || {}
    let $vars = this.$vars || {}

    let testDir = $ctx.testDir || $vars.TEST_DEFAULT_DIR

    return {
      'test:mkdir': mkdir([
        `${testDir}`
      ]),
      'test:render': coz([
        `${testDir}/**/.*.bud`
      ])
    }
  },
  /**
   * apeman watch configurations.
   * @see https://github.com/apeman-cmd-labo/apeman-wtch
   */
  get $wtchs () {
    let $ctx = this.$ctx || {}
    let $vars = this.$vars || {}

    let testDir = $ctx.testDir || $vars.TEST_DEFAULT_DIR

    return {
      'test:render': {
        pattern: [
          `${testDir}/**/.*.bud`
        ],
        action: (ev, filename) => {
          require('coz').render(filename)
        }
      }
    }
  },
  /** Note about properties. */
  get $notes () {
    return {
      '$wtchs.test:render': 'Watch to render bud files.'
    }
  },
  /** Commands which need to be installed in advance. */
  get $needs () {
    return {}
  },

  get $vars () {
    return {
      TEST_DEFAULT_DIR: 'test'
    }
  }
}

if (!module.parent) {
  // Execute this file as apeman bin.
  require('apeman').cli(process.argv)
}
